package TestApp::View::ReproxyFile;

use strict;
use warnings;

use base qw/Catalyst::View::Reproxy/;

=head1 NAME

TestApp::View::ReproxyFile - Catalyst::View::Reproxy sub class.

=head1 SYNOPSIS

SEE L<TestApp>

=head1 DESCRIPTION

SEE L<Catalyst::View::Reproxy>

=head1 AUTHOR

Toru Yamaguchi

=head1 LICENSE

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1;
